@@ -126,11 +126,11 @@ sub tests {
               keys %{ $conf->{vhostOptions} };
 
             foreach my $alias (@aliases) {
-                    push @all_aliases, split(/\s+/, $alias);
+                push @all_aliases, split( /\s+/, $alias );
             }
 
             foreach my $vh ( keys %{ $conf->{locationRules} } ) {
-                push @pb, $vh if ( grep /^$vh$/, @all_aliases );
+                push @pb, $vh if ( grep { lc($_) eq lc($vh) } @all_aliases );
             }
             return @pb
               ? ( 0, 'Virtual hosts ' . join( ', ', @pb ) . ' match an alias' )
@@ -835,7 +835,7 @@ sub tests {
                     ->{oidcRPMetaDataOptionsRedirectUris} )
                 {
                     push @msg,
-                      "$oidcRpId OpenID Connect RP has no redirect URI defined";
+"$oidcRpId: OIDC Relying Party has no redirect URI defined";
                     $res = 0;
                     next;
                 }
@@ -843,6 +843,26 @@ sub tests {
             return ( $res, join( ', ', @msg ) );
         },
 
+        # OIDC public RP should implement PKCE
+        oidcRPpublicClientWithPKCE => sub {
+            return 1
+              unless ( $conf->{oidcRPMetaDataOptions}
+                and %{ $conf->{oidcRPMetaDataOptions} } );
+            my @msg;
+            foreach my $oidcRpId ( keys %{ $conf->{oidcRPMetaDataOptions} } ) {
+                if ( $conf->{oidcRPMetaDataOptions}->{$oidcRpId}
+                    ->{oidcRPMetaDataOptionsPublic} )
+                {
+                    push @msg,
+"$oidcRpId: requiring PKCE is recommended for public OIDC Relying Parties"
+                      unless $conf->{oidcRPMetaDataOptions}->{$oidcRpId}
+                      ->{oidcRPMetaDataOptionsRequirePKCE};
+                    next;
+                }
+            }
+            return ( 1, join( ', ', @msg ) );
+        },
+
         # Test if SAML private and public keys signature keys are set
         oidcSecretKeys => sub {
             return 1 unless ( $conf->{issuerDBOpenIDConnectActivation} );
@@ -925,7 +945,7 @@ sub tests {
                   ->{oidcRPMetaDataOptionsClientID};
                 unless ($clientId) {
                     push @msg,
-                      "$clientConfKey OIDC Relying Party has no Client ID";
+                      "$clientConfKey: OIDC Relying Party has no Client ID";
                     $res = 0;
                     next;
                 }
@@ -977,7 +997,7 @@ sub tests {
                     my ($appHost) = $appUrl =~ m#^(https?://[^/]+)(/.*)?$#;
                     unless ($appHost) {
                         push @msg,
-                          "$casConfKey CAS Application has no Service URL";
+                          "$casConfKey: CAS Application has no Service URL";
                         $res = 0;
                         next;
                     }
@@ -1290,6 +1310,63 @@ sub tests {
                 and $conf->{passwordPolicyActivation} );
             return 1;
         },
+        accessTokenConsistency => sub {
+            return 1
+              unless $conf->{issuerDBOpenIDConnectActivation};
+            my @pb;
+            foreach my $rp ( keys %{ $conf->{oidcRPMetaDataOptions} || {} } ) {
+                my $opts = $conf->{oidcRPMetaDataOptions}->{$rp};
+                push @pb, $rp
+                  if $opts->{oidcRPMetaDataOptionsAccessTokenClaims}
+                  and not $opts->{oidcRPMetaDataOptionsAccessTokenJWT};
+            }
+            return 1 unless @pb;
+            return ( 0,
+                'access_token cannot be opaque with claims in access_token ('
+                  . join( ', ', @pb )
+                  . ')' );
+        },
+        oidcNoneConsistency => sub {
+            my @pb;
+            return 1 unless $conf->{oidcServiceMetaDataDisallowNoneAlg};
+            foreach my $rp ( keys %{ $conf->{oidcRPMetaDataOptions} || {} } ) {
+                my $opts = $conf->{oidcRPMetaDataOptions}->{$rp};
+                push @pb, $rp
+                  if $opts->{oidcRPMetaDataOptionsIDTokenSignAlg} eq 'none'
+                  or $opts->{oidcRPMetaDataOptionsUserInfoSignAlg} eq 'none';
+            }
+            return 1 unless @pb;
+            return ( 1,
+                'Signature algorithm is not allowed but set for: '
+                  . join( ', ', @pb ) );
+        },
+        oidcNativeSso => sub {
+            return ( 0, 'Native SSO without OIDC identity service' )
+              if $conf->{oidcServiceAllowNativeSso}
+              and not $conf->{issuerDBOpenIDConnectActivation};
+            return 1
+              unless $conf->{oidcRPMetaDataOptions}
+              and ref $conf->{oidcRPMetaDataOptions};
+            my @needNativeSso;
+            if ( $conf->{oidcRPMetaDataOptions}
+                and ref $conf->{oidcRPMetaDataOptions} )
+            {
+                for my $rp ( keys %{ $conf->{oidcRPMetaDataOptions} } ) {
+                    push @needNativeSso, $rp
+                      if $conf->{oidcRPMetaDataOptions}->{$rp}
+                      ->{oidcRPMetaDataOptionsAllowNativeSso};
+                }
+            }
+            if ( @needNativeSso and not $conf->{oidcServiceAllowNativeSso} ) {
+                return ( 1,
+                    "Native SSO isn't enabled but needed by: "
+                      . join( ', ', @needNativeSso ) );
+            }
+            if ( !@needNativeSso and $conf->{oidcServiceAllowNativeSso} ) {
+                return ( 1, 'Native SSO service enabled but useless' );
+            }
+            return 1;
+        },
     };
 }
 
